'''
Manage CDN endpoints.
'''
from ... pyaz_utils import _call_az
from . import rule


def start(name, profile_name, resource_group, no_wait=None):
    '''
    Start a CDN endpoint.

    Required Parameters:
    - name -- Name of the CDN endpoint.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az cdn endpoint start", locals())


def stop(name, profile_name, resource_group, no_wait=None):
    '''
    Stop a CDN endpoint.

    Required Parameters:
    - name -- Name of the CDN endpoint.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az cdn endpoint stop", locals())


def delete(name, profile_name, resource_group, no_wait=None):
    '''
    Delete a CDN endpoint.

    Required Parameters:
    - name -- Name of the CDN endpoint.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az cdn endpoint delete", locals())


def show(name, profile_name, resource_group):
    '''
    

    Required Parameters:
    - name -- Name of the CDN endpoint.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cdn endpoint show", locals())


def list(profile_name, resource_group):
    '''
    List available endpoints for a CDN.

    Required Parameters:
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cdn endpoint list", locals())


def load(content_paths, name, profile_name, resource_group, no_wait=None):
    '''
    Pre-load content for a CDN endpoint.

    Required Parameters:
    - content_paths -- None
    - name -- Name of the CDN endpoint.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az cdn endpoint load", locals())


def purge(content_paths, name, profile_name, resource_group, no_wait=None):
    '''
    Purge pre-loaded content for a CDN endpoint.

    Required Parameters:
    - content_paths -- None
    - name -- Name of the CDN endpoint.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az cdn endpoint purge", locals())


def validate_custom_domain(host_name, name, profile_name, resource_group):
    '''
    Validates the custom domain mapping to ensure it maps to the correct CDN endpoint in DNS.

    Required Parameters:
    - host_name -- None
    - name -- Name of the CDN endpoint.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cdn endpoint validate-custom-domain", locals())


def create(name, origin, profile_name, resource_group, content_types_to_compress=None, enable_compression=None, location=None, no_http=None, no_https=None, no_wait=None, origin_host_header=None, origin_path=None, query_string_caching_behavior=None, tags=None):
    '''
    Create a named endpoint to connect to a CDN.

    Required Parameters:
    - name -- Name of the CDN endpoint.
    - origin -- Endpoint origin specified by the following space-delimited 6 tuple: `www.example.com http_port https_port private_link_resource_id private_link_location private_link_approval_message`. The HTTP and HTTPS ports and the private link resource ID and location are optional. The HTTP and HTTPS ports default to 80 and 443, respectively. Private link fields are only valid for the sku Standard_Microsoft, and private_link_location is required if private_link_resource_id is set.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - content_types_to_compress -- List of content types on which compression applies. The value should be a valid MIME type.
    - enable_compression -- If compression is enabled, content will be served as compressed if user requests for a compressed version. Content won't be compressed on CDN when requested content is smaller than 1 byte or larger than 1 MB.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_http -- Indicates whether HTTP traffic is not allowed on the endpoint. Default is to allow HTTP traffic.
    - no_https -- Indicates whether HTTPS traffic is not allowed on the endpoint. Default is to allow HTTPS traffic.
    - no_wait -- Do not wait for the long-running operation to finish.
    - origin_host_header -- The host header value sent to the origin with each request. This property at Endpoint is only allowed when endpoint uses single origin and can be overridden by the same property specified at origin.If you leave this blank, the request hostname determines this value. Azure CDN origins, such as Web Apps, Blob Storage, and Cloud Services require this host header value to match the origin hostname by default.
    - origin_path -- A directory path on the origin that CDN can use to retrieve content from, e.g. contoso.cloudapp.net/originpath.
    - query_string_caching_behavior -- Defines how CDN caches requests that include query strings. You can ignore any query strings when caching, bypass caching to prevent requests that contain query strings from being cached, or cache every request with a unique URL. Possible values include: "IgnoreQueryString", "BypassCaching", "UseQueryString", "NotSet".
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az cdn endpoint create", locals())


def update(name, profile_name, resource_group, add=None, content_types_to_compress=None, default_origin_group=None, enable_compression=None, force_string=None, no_http=None, no_https=None, no_wait=None, origin_host_header=None, origin_path=None, query_string_caching=None, remove=None, set=None, tags=None):
    '''
    Update a CDN endpoint to manage how content is delivered.

    Required Parameters:
    - name -- Name of the CDN endpoint.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - content_types_to_compress -- List of content types on which compression applies. The value should be a valid MIME type.
    - default_origin_group -- A reference to the origin group.
    - enable_compression -- If compression is enabled, content will be served as compressed if user requests for a compressed version. Content won't be compressed on CDN when requested content is smaller than 1 byte or larger than 1 MB.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - no_http -- Indicates whether HTTP traffic is not allowed on the endpoint. Default is to allow HTTP traffic.
    - no_https -- Indicates whether HTTPS traffic is not allowed on the endpoint. Default is to allow HTTPS traffic.
    - no_wait -- Do not wait for the long-running operation to finish.
    - origin_host_header -- The host header value sent to the origin with each request. This property at Endpoint is only allowed when endpoint uses single origin and can be overridden by the same property specified at origin.If you leave this blank, the request hostname determines this value. Azure CDN origins, such as Web Apps, Blob Storage, and Cloud Services require this host header value to match the origin hostname by default.
    - origin_path -- A directory path on the origin that CDN can use to retrieve content from, e.g. contoso.cloudapp.net/originpath.
    - query_string_caching -- Defines how CDN caches requests that include query strings. You can ignore any query strings when caching, bypass caching to prevent requests that contain query strings from being cached, or cache every request with a unique URL. Possible values include: "IgnoreQueryString", "BypassCaching", "UseQueryString", "NotSet".
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az cdn endpoint update", locals())




from ... pyaz_utils import _call_az

def list(account_name, invoice_section_name=None, profile_name=None):
    '''
    List the role assignments for the caller on a billing account. The operation is supported for billing accounts with agreement type Microsoft Partner Agreement or Microsoft Customer Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.

    Optional Parameters:
    - invoice_section_name -- The ID that uniquely identifies an invoice section.
    - profile_name -- The ID that uniquely identifies a billing profile.
    '''
    return _call_az("az billing role-assignment list", locals())


def delete(account_name, name, invoice_section_name=None, profile_name=None, yes=None):
    '''
    Delete a role assignment for the caller on a billing account. The operation is supported for billing accounts with agreement type Microsoft Partner Agreement or Microsoft Customer Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - name -- The ID that uniquely identifies a role assignment.

    Optional Parameters:
    - invoice_section_name -- The ID that uniquely identifies an invoice section.
    - profile_name -- The ID that uniquely identifies a billing profile.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az billing role-assignment delete", locals())


def show(account_name, name, invoice_section_name=None, profile_name=None):
    '''
    Show the role assignment detail for the caller within different scopes. The operation is supported for billing accounts with agreement type Microsoft Partner Agreement or Microsoft Customer Agreement.

    Required Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - name -- The ID that uniquely identifies a role assignment.

    Optional Parameters:
    - invoice_section_name -- The ID that uniquely identifies an invoice section.
    - profile_name -- The ID that uniquely identifies a billing profile.
    '''
    return _call_az("az billing role-assignment show", locals())




from ... pyaz_utils import _call_az

def on():
    '''
    Turn on parameter persistence.
    '''
    return _call_az("az config param-persist on", locals())


def off():
    '''
    Turn off parameter persistence.
    '''
    return _call_az("az config param-persist off", locals())


def show():
    '''
    Show parameter persistence data.
    '''
    return _call_az("az config param-persist show", locals())


def delete(all=None, purge=None, recursive=None, yes=None):
    '''
    Delete parameter persistence data.

    Optional Parameters:
    - all -- Clear all parameter persistence data. Either positional name argument  or --all can be specified.
    - purge -- Delete parameter persistence file from working directory. Only available when --all is specified.
    - recursive -- Indicate this is recursive delete of parameter persistence. Only available when --all is specified.
    - yes -- Do not prompt for confirmation. Only available when --all is specified.
    '''
    return _call_az("az config param-persist delete", locals())




from ..... pyaz_utils import _call_az

def list():
    '''
    Lists all SSL predefined policies for configuring SSL policy.
    '''
    return _call_az("az network application-gateway ssl-policy predefined list", locals())


def show(name):
    '''
    Gets SSL predefined policy with the specified policy name.

    Required Parameters:
    - name -- Name of Ssl predefined policy.
    '''
    return _call_az("az network application-gateway ssl-policy predefined show", locals())




'''
Manage databases.
'''
from ... pyaz_utils import _call_az
from . import audit_policy, classification, ledger_digest_uploads, ltr_backup, ltr_policy, op, replica, str_policy, tde, threat_policy


def show_connection_string(client, auth_type=None, name=None, server=None):
    '''
    Generates a connection string to a database.

    Required Parameters:
    - client -- Type of client connection provider.

    Optional Parameters:
    - auth_type -- Type of authentication.
    - name -- Name of the Azure SQL Database.
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql db show-connection-string", locals())


def create(name, resource_group, server, auto_pause_delay=None, backup_storage_redundancy=None, capacity=None, catalog_collation=None, collation=None, compute_model=None, elastic_pool=None, family=None, ledger_on=None, license_type=None, maint_config_id=None, max_size=None, min_capacity=None, no_wait=None, read_replicas=None, read_scale=None, sample_name=None, service_objective=None, tags=None, tier=None, yes=None, zone_redundant=None):
    '''
    Create a database.

    Required Parameters:
    - name -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - auto_pause_delay -- Time in minutes after which database is automatically paused. A value of -1 means that automatic pause is disabled.
    - backup_storage_redundancy -- Backup storage redundancy used to store backups. Allowed values include: Local, Zone, Geo.
    - capacity -- The capacity component of the sku in integer number of DTUs or vcores.
    - catalog_collation -- Collation of the metadata catalog. Possible values include: "DATABASE_DEFAULT", "SQL_Latin1_General_CP1_CI_AS".
    - collation -- The collation of the database.
    - compute_model -- The compute model of the database.
    - elastic_pool -- The name or resource id of the elastic pool to create the database in.
    - family -- The compute generation component of the sku (for vcore skus only). Allowed values include: Gen4, Gen5.
    - ledger_on -- Create a ledger database, in which the integrity of all data is protected by the ledger feature. All tables in the ledger database must be ledger tables. Note: the value of this property cannot be changed after the database has been created. 
    - license_type -- The license type to apply for this database. ``LicenseIncluded`` if you need a license, or ``BasePrice`` if you have a license and are eligible for the Azure Hybrid Benefit. Possible values include: "LicenseIncluded", "BasePrice".
    - maint_config_id -- Specified maintenance configuration id or name for this resource.
    - max_size -- The max storage size. If no unit is specified, defaults to bytes (B).
    - min_capacity -- Minimal capacity that database will always have allocated, if not paused
    - no_wait -- Do not wait for the long-running operation to finish.
    - read_replicas -- The number of high availability replicas to provision for the database. Only settable for Hyperscale edition.
    - read_scale -- If enabled, connections that have application intent set to readonly in their connection string may be routed to a readonly secondary replica. This property is only settable for Premium and Business Critical databases.
    - sample_name -- The name of the sample schema to apply when creating this database. Possible values include: "AdventureWorksLT", "WideWorldImportersStd", "WideWorldImportersFull".
    - service_objective -- The service objective for the new database. For example: Basic, S0, P1, GP_Gen4_1, GP_Gen5_S_8, BC_Gen5_2, HS_Gen5_32.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - tier -- The edition component of the sku. Allowed values include: Basic, Standard, Premium, GeneralPurpose, BusinessCritical, Hyperscale.
    - yes -- Do not prompt for confirmation.
    - zone_redundant -- Specifies whether to enable zone redundancy
    '''
    return _call_az("az sql db create", locals())


def copy(dest_name, name, resource_group, server, auto_pause_delay=None, backup_storage_redundancy=None, capacity=None, compute_model=None, dest_resource_group=None, dest_server=None, elastic_pool=None, family=None, license_type=None, min_capacity=None, no_wait=None, read_replicas=None, read_scale=None, service_objective=None, tags=None, zone_redundant=None):
    '''
    Create a copy of a database.

    Required Parameters:
    - dest_name -- Name of the database that will be created as the copy destination.
    - name -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - auto_pause_delay -- Time in minutes after which database is automatically paused. A value of -1 means that automatic pause is disabled.
    - backup_storage_redundancy -- Backup storage redundancy used to store backups. Allowed values include: Local, Zone, Geo.
    - capacity -- The capacity component of the sku in integer number of DTUs or vcores.
    - compute_model -- The compute model of the database.
    - dest_resource_group -- Name of the resouce group to create the copy in. If unspecified, defaults to the origin resource group.
    - dest_server -- Name of the server to create the copy in. If unspecified, defaults to the origin server.
    - elastic_pool -- The name or resource id of the elastic pool to create the database in.
    - family -- The compute generation component of the sku (for vcore skus only). Allowed values include: Gen4, Gen5.
    - license_type -- The license type to apply for this database. ``LicenseIncluded`` if you need a license, or ``BasePrice`` if you have a license and are eligible for the Azure Hybrid Benefit. Possible values include: "LicenseIncluded", "BasePrice".
    - min_capacity -- Minimal capacity that database will always have allocated, if not paused
    - no_wait -- Do not wait for the long-running operation to finish.
    - read_replicas -- The number of high availability replicas to provision for the database. Only settable for Hyperscale edition.
    - read_scale -- If enabled, connections that have application intent set to readonly in their connection string may be routed to a readonly secondary replica. This property is only settable for Premium and Business Critical databases.
    - service_objective -- The service objective for the new database. For example: Basic, S0, P1, GP_Gen4_1, GP_Gen5_S_8, BC_Gen5_2, HS_Gen5_32.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - zone_redundant -- Specifies whether to enable zone redundancy
    '''
    return _call_az("az sql db copy", locals())


def restore(dest_name, name, resource_group, server, auto_pause_delay=None, backup_storage_redundancy=None, capacity=None, compute_model=None, deleted_time=None, elastic_pool=None, family=None, license_type=None, min_capacity=None, no_wait=None, read_replicas=None, read_scale=None, service_objective=None, tags=None, tier=None, time=None, zone_redundant=None):
    '''
    Create a new database by restoring from a backup.

    Required Parameters:
    - dest_name -- Name of the database that will be created as the restore destination.
    - name -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - auto_pause_delay -- Time in minutes after which database is automatically paused. A value of -1 means that automatic pause is disabled.
    - backup_storage_redundancy -- Backup storage redundancy used to store backups. Allowed values include: Local, Zone, Geo.
    - capacity -- The capacity component of the sku in integer number of DTUs or vcores.
    - compute_model -- The compute model of the database.
    - deleted_time -- If specified, restore from a deleted database instead of from an existing database. Must match the deleted time of a deleted database in the same server. Either --time or --deleted-time (or both) must be specified. Time should be in following format: "YYYY-MM-DDTHH:MM:SS".
    - elastic_pool -- The name or resource id of the elastic pool to create the database in.
    - family -- The compute generation component of the sku (for vcore skus only). Allowed values include: Gen4, Gen5.
    - license_type -- The license type to apply for this database. ``LicenseIncluded`` if you need a license, or ``BasePrice`` if you have a license and are eligible for the Azure Hybrid Benefit. Possible values include: "LicenseIncluded", "BasePrice".
    - min_capacity -- Minimal capacity that database will always have allocated, if not paused
    - no_wait -- Do not wait for the long-running operation to finish.
    - read_replicas -- The number of high availability replicas to provision for the database. Only settable for Hyperscale edition.
    - read_scale -- If enabled, connections that have application intent set to readonly in their connection string may be routed to a readonly secondary replica. This property is only settable for Premium and Business Critical databases.
    - service_objective -- The service objective for the new database. For example: Basic, S0, P1, GP_Gen4_1, GP_Gen5_S_8, BC_Gen5_2, HS_Gen5_32.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - tier -- The edition component of the sku. Allowed values include: Basic, Standard, Premium, GeneralPurpose, BusinessCritical, Hyperscale.
    - time -- The point in time of the source database that will be restored to create the new database. Must be greater than or equal to the source database's earliestRestoreDate value. Either --time or --deleted-time (or both) must be specified. Time should be in following format: "YYYY-MM-DDTHH:MM:SS".
    - zone_redundant -- Specifies whether to enable zone redundancy
    '''
    return _call_az("az sql db restore", locals())


def rename(name, new_name, resource_group, server):
    '''
    Rename a database.

    Required Parameters:
    - name -- Name of the Azure SQL Database.
    - new_name -- The new name that the database will be renamed to.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql db rename", locals())


def show(name, resource_group, server):
    '''
    Get the details for a database.

    Required Parameters:
    - name -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql db show", locals())


def list(resource_group, server, elastic_pool=None):
    '''
    List databases on a server or elastic pool.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - elastic_pool -- If specified, lists only the databases in this elastic pool
    '''
    return _call_az("az sql db list", locals())


def delete(name, resource_group, server, no_wait=None, yes=None):
    '''
    Delete a database.

    Required Parameters:
    - name -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az sql db delete", locals())


def update(name, resource_group, server, add=None, auto_pause_delay=None, backup_storage_redundancy=None, capacity=None, compute_model=None, elastic_pool=None, family=None, force_string=None, maint_config_id=None, max_size=None, min_capacity=None, no_wait=None, read_replicas=None, read_scale=None, remove=None, service_objective=None, set=None, tier=None, zone_redundant=None):
    '''
    Update a database.

    Required Parameters:
    - name -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - auto_pause_delay -- Time in minutes after which database is automatically paused. A value of -1 means that automatic pause is disabled.
    - backup_storage_redundancy -- Backup storage redundancy used to store backups. Allowed values include: Local, Zone, Geo.
    - capacity -- The capacity component of the sku in integer number of DTUs or vcores.
    - compute_model -- The compute model of the database.
    - elastic_pool -- The name or resource id of the elastic pool to move the database into.
    - family -- The compute generation component of the sku (for vcore skus only). Allowed values include: Gen4, Gen5.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - maint_config_id -- Specified maintenance configuration id or name for this resource.
    - max_size -- The new maximum size of the database expressed in bytes.
    - min_capacity -- Minimal capacity that database will always have allocated, if not paused
    - no_wait -- Do not wait for the long-running operation to finish.
    - read_replicas -- The number of high availability replicas to provision for the database. Only settable for Hyperscale edition.
    - read_scale -- If enabled, connections that have application intent set to readonly in their connection string may be routed to a readonly secondary replica. This property is only settable for Premium and Business Critical databases.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - service_objective -- The name of the new service objective. If this is a standalone db service objective and the db is currently in an elastic pool, then the db is removed from the pool.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tier -- The edition component of the sku. Allowed values include: Basic, Standard, Premium, GeneralPurpose, BusinessCritical, Hyperscale.
    - zone_redundant -- Specifies whether to enable zone redundancy
    '''
    return _call_az("az sql db update", locals())


def export(admin_password, admin_user, name, resource_group, server, storage_key, storage_key_type, storage_uri, auth_type=None):
    '''
    Export a database to a bacpac.

    Required Parameters:
    - admin_password -- Required. Administrator login password.
    - admin_user -- Required. Administrator login name.
    - name -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    - storage_key -- Required. Storage key.
    - storage_key_type -- Required. Storage key type. Possible values include: "SharedAccessKey", "StorageAccessKey".
    - storage_uri -- Required. Storage Uri.

    Optional Parameters:
    - auth_type -- Authentication type.
    '''
    return _call_az("az sql db export", locals())


def import_(admin_password, admin_user, name, resource_group, server, storage_key, storage_key_type, storage_uri, auth_type=None):
    '''
    Imports a bacpac into an existing database.

    Required Parameters:
    - admin_password -- Required. Administrator login password.
    - admin_user -- Required. Administrator login name.
    - name -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    - storage_key -- Required. Storage key.
    - storage_key_type -- Required. Storage key type. Possible values include: "SharedAccessKey", "StorageAccessKey".
    - storage_uri -- Required. Storage Uri.

    Optional Parameters:
    - auth_type -- Authentication type.
    '''
    return _call_az("az sql db import", locals())


def list_editions(location, available=None, dtu=None, service_objective=None, show_details=None, tier=None, vcores=None):
    '''
    Show database editions available for the currently active subscription.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.

    Optional Parameters:
    - available -- If specified, show only results that are available in the specified region.
    - dtu -- Number of DTUs to search for. If unspecified, all DTU sizes are shown.
    - service_objective -- Service objective to search for. If unspecified, all service objectives are shown.
    - show_details -- List of additional details to include in output.
    - tier -- Edition to search for. If unspecified, all editions are shown.
    - vcores -- Number of vcores to search for. If unspecified, all vcore sizes are shown.
    '''
    return _call_az("az sql db list-editions", locals())


def list_deleted(resource_group, server):
    '''
    

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql db list-deleted", locals())


def list_usages(name, resource_group, server):
    '''
    

    Required Parameters:
    - name -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    '''
    return _call_az("az sql db list-usages", locals())




'''
Manage taskruns using Azure Container Registries.
'''
from ... pyaz_utils import _call_az

def list(registry, resource_group=None):
    '''
    List the taskruns for an Azure Container Registry.

    Required Parameters:
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr taskrun list", locals())


def delete(name, registry, resource_group=None, yes=None):
    '''
    Delete a taskrun from an Azure Container Registry.

    Required Parameters:
    - name -- The name of the taskrun.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az acr taskrun delete", locals())


def show(name, registry, resource_group=None):
    '''
    Get the properties of a named taskrun for an Azure Container Registry.

    Required Parameters:
    - name -- The name of the taskrun.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr taskrun show", locals())


def logs(name, registry, resource_group=None):
    '''
    Show run logs for a particular taskrun.

    Required Parameters:
    - name -- The name of the taskrun.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr taskrun logs", locals())




from .... pyaz_utils import _call_az

def list(application_name, gallery_name, resource_group):
    '''
    

    Required Parameters:
    - application_name -- The name of the gallery Application
    - gallery_name -- gallery name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sig gallery-application version list", locals())


def show(application_name, gallery_name, name, resource_group, expand=None):
    '''
    

    Required Parameters:
    - application_name -- The name of the gallery Application
    - gallery_name -- gallery name
    - name -- The name of the gallery Application Version
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - expand -- The expand expression to apply on the operation.
    '''
    return _call_az("az sig gallery-application version show", locals())


def create(application_name, gallery_name, install_command, name, package_file_link, remove_command, resource_group, default_file_link=None, end_of_life_date=None, exclude_from=None, location=None, no_wait=None, tags=None, target_regions=None, update_command=None):
    '''
    Create a gallery Application Version.

    Required Parameters:
    - application_name -- The name of the gallery Application
    - gallery_name -- gallery name
    - install_command -- The path and arguments to install the gallery application.
    - name -- The name of the gallery Application Version
    - package_file_link -- The mediaLink of the artifact, must be a readable storage page blob.
    - remove_command -- The path and arguments to remove the gallery application.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - default_file_link -- The default configuration link of the artifact, must be a readable storage page blob.
    - end_of_life_date -- The end of life date of the gallery image version. This property can be used for decommissioning purposes. This property is updatable.
    - exclude_from -- If set to true, Virtual Machines deployed from the latest version of the Image Definition won't use this Image Version.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_wait -- Do not wait for the long-running operation to finish.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - target_regions -- The target regions where the Image Version is going to be replicated to. This property is updatable. Expected value: json-string/json-file/@json-file.
    - update_command -- The path and arguments to update the gallery application. If not present, then update operation will invoke remove command on the previous version and install command on the current version of the gallery application.
    '''
    return _call_az("az sig gallery-application version create", locals())


def update(application_name, gallery_name, name, package_file_link, resource_group, default_file_link=None, end_of_life_date=None, exclude_from=None, location=None, no_wait=None, tags=None, target_regions=None):
    '''
    Update a gallery Application Version.

    Required Parameters:
    - application_name -- The name of the gallery Application
    - gallery_name -- gallery name
    - name -- The name of the gallery Application Version
    - package_file_link -- The mediaLink of the artifact, must be a readable storage page blob.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - default_file_link -- The default configuration link of the artifact, must be a readable storage page blob.
    - end_of_life_date -- The end of life date of the gallery image version. This property can be used for decommissioning purposes. This property is updatable.
    - exclude_from -- If set to true, Virtual Machines deployed from the latest version of the Image Definition won't use this Image Version.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_wait -- Do not wait for the long-running operation to finish.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - target_regions -- The target regions where the Image Version is going to be replicated to. This property is updatable. Expected value: json-string/json-file/@json-file.
    '''
    return _call_az("az sig gallery-application version update", locals())


def delete(application_name, gallery_name, name, resource_group, no_wait=None, yes=None):
    '''
    

    Required Parameters:
    - application_name -- The name of the gallery Application
    - gallery_name -- gallery name
    - name -- The name of the gallery Application Version
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az sig gallery-application version delete", locals())




'''
Manage Azure Kusto clusters.
'''
from ... pyaz_utils import _call_az

def create(name, resource_group, sku, capacity=None, location=None, no_wait=None):
    '''
    Create a Kusto cluster.

    Required Parameters:
    - name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sku -- The name of the sku.

    Optional Parameters:
    - capacity -- The instance number of the VM.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az kusto cluster create", locals())


def stop(name, resource_group, no_wait=None):
    '''
    Stop a Kusto cluster.

    Required Parameters:
    - name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az kusto cluster stop", locals())


def start(name, resource_group, no_wait=None):
    '''
    Start a Kusto cluster.

    Required Parameters:
    - name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az kusto cluster start", locals())


def list(resource_group):
    '''
    List a Kusto cluster.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az kusto cluster list", locals())


def show(name, resource_group):
    '''
    Get a Kusto cluster.

    Required Parameters:
    - name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az kusto cluster show", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete a Kusto cluster.

    Required Parameters:
    - name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az kusto cluster delete", locals())


def update(name, resource_group, add=None, capacity=None, force_string=None, remove=None, set=None, sku=None):
    '''
    Update a Kusto cluster.

    Required Parameters:
    - name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - capacity -- The instance number of the VM.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - sku -- The name of the sku.
    '''
    return _call_az("az kusto cluster update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Wait for a managed Kusto cluster to reach a desired state.

    Required Parameters:
    - name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az kusto cluster wait", locals())




from .... pyaz_utils import _call_az

def show(account_name, backup_policy_name, resource_group):
    '''
    Get the specified ANF backup policy.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - backup_policy_name -- The name of the backup policy
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az netappfiles account backup-policy show", locals())


def list(account_name, resource_group):
    '''
    List the ANF backup policy for the specified account.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az netappfiles account backup-policy list", locals())


def delete(account_name, backup_policy_name, resource_group):
    '''
    Delete the specified ANF backup policy.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - backup_policy_name -- The name of the backup policy
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az netappfiles account backup-policy delete", locals())


def update(account_name, backup_policy_name, resource_group, daily_backups=None, enabled=None, location=None, monthly_backups=None, tags=None, weekly_backups=None):
    '''
    Update the specified ANF backup policy.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - backup_policy_name -- The name of the backup policy
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - daily_backups -- Daily backups count to keep
    - enabled -- The property to decide policy is enabled or not.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - monthly_backups -- Monthly backups count to keep
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - weekly_backups -- Weekly backups count to keep
    '''
    return _call_az("az netappfiles account backup-policy update", locals())


def create(account_name, backup_policy_name, location, resource_group, daily_backups=None, enabled=None, monthly_backups=None, tags=None, weekly_backups=None):
    '''
    Create a new Azure NetApp Files (ANF) backup policy.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - backup_policy_name -- The name of the backup policy
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - daily_backups -- Daily backups count to keep
    - enabled -- The property to decide policy is enabled or not.
    - monthly_backups -- Monthly backups count to keep
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - weekly_backups -- Weekly backups count to keep
    '''
    return _call_az("az netappfiles account backup-policy create", locals())




'''
Manage Azure Cosmos DB Cassandra keyspaces.
'''
from .... pyaz_utils import _call_az
from . import throughput


def create(account_name, name, resource_group, max_throughput=None, throughput=None):
    '''
    Create an Cassandra keyspace under an Azure Cosmos DB account.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - name -- Keyspace name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - max_throughput -- The maximum throughput resource can scale to (RU/s). Provided when the resource is autoscale enabled. The minimum value can be 4000 (RU/s)
    - throughput -- The throughput of Cassandra keyspace (RU/s). Default value is 400
    '''
    return _call_az("az cosmosdb cassandra keyspace create", locals())


def exists(account_name, name, resource_group):
    '''
    

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - name -- Keyspace name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb cassandra keyspace exists", locals())


def list(account_name, resource_group):
    '''
    List the Cassandra keyspaces under an Azure Cosmos DB account.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb cassandra keyspace list", locals())


def show(account_name, name, resource_group):
    '''
    Show the details of a Cassandra keyspace under an Azure Cosmos DB account.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - name -- Keyspace name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb cassandra keyspace show", locals())


def delete(account_name, name, resource_group, yes=None):
    '''
    Delete the Cassandra keyspace under an Azure Cosmos DB account.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - name -- Keyspace name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az cosmosdb cassandra keyspace delete", locals())




'''
Manage Data Lake Analytics catalog schemas.
'''
from .... pyaz_utils import _call_az

def show(account, database_name, schema_name):
    '''
    

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.
    - database_name -- The name of the database containing the schema.
    - schema_name -- The name of the schema.
    '''
    return _call_az("az dla catalog schema show", locals())


def list(account, database_name, count=None, filter=None, orderby=None, select=None, skip=None, top=None):
    '''
    

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.
    - database_name -- The name of the database containing the schema.

    Optional Parameters:
    - count -- The Boolean value of true or false to request a count of the matching resources included with the resources in the response, e.g. Categories?$count=true.
    - filter -- OData filter. Optional.
    - orderby -- OrderBy clause. One or more comma-separated expressions with an optional "asc" (the default) or "desc" depending on the order you'd like the values sorted, e.g. Categories?$orderby=CategoryName desc. Optional.
    - select -- OData Select statement. Limits the properties on each entry to just those requested, e.g. Categories?$select=CategoryName,Description. Optional.
    - skip -- The number of items to skip over before returning elements.
    - top -- Maximum number of items to return.
    '''
    return _call_az("az dla catalog schema list", locals())




from ... pyaz_utils import _call_az
from . import authorization_rule


def set(alias, namespace_name, partner_namespace, resource_group, alternate_name=None):
    '''
    Sets a Geo-Disaster Recovery Configuration Alias for the give Namespace

    Required Parameters:
    - alias -- Name of Geo-Disaster Recovery Configuration Alias
    - namespace_name -- name of Namespace
    - partner_namespace -- Name (if within the same resource group) or ARM Id of the Primary/Secondary eventhub namespace name, which is part of GEO DR pairing
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - alternate_name -- Alternate Name for the Alias, when the Namespace name and Alias name are same
    '''
    return _call_az("az eventhubs georecovery-alias set", locals())


def show(alias, namespace_name, resource_group):
    '''
    shows properties of Geo-Disaster Recovery Configuration Alias for Primay or Secondary Namespace

    Required Parameters:
    - alias -- Name of Geo-Disaster Recovery Configuration Alias
    - namespace_name -- name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventhubs georecovery-alias show", locals())


def list(namespace_name, resource_group):
    '''
    

    Required Parameters:
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventhubs georecovery-alias list", locals())


def break_pair(alias, namespace_name, resource_group):
    '''
    Disables Geo-Disaster Recovery Configuration Alias and stops replicating changes from primary to secondary namespaces

    Required Parameters:
    - alias -- Name of Geo-Disaster Recovery Configuration Alias
    - namespace_name -- name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventhubs georecovery-alias break-pair", locals())


def fail_over(alias, namespace_name, resource_group):
    '''
    Invokes Geo-Disaster Recovery Configuration Alias to point to the secondary namespace

    Required Parameters:
    - alias -- Name of Geo-Disaster Recovery Configuration Alias
    - namespace_name -- name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventhubs georecovery-alias fail-over", locals())


def exists(alias, namespace_name, resource_group):
    '''
    Check the availability of Geo-Disaster Recovery Configuration Alias Name

    Required Parameters:
    - alias -- Name of Geo Recovery Configs - Alias to check availability
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventhubs georecovery-alias exists", locals())


def delete(alias, namespace_name, resource_group):
    '''
    Delete Geo-Disaster Recovery Configuration Alias

    Required Parameters:
    - alias -- Name of Geo-Disaster Recovery Configuration Alias
    - namespace_name -- name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventhubs georecovery-alias delete", locals())




from ... pyaz_utils import _call_az

def delete(name, resource_group, no_wait=None):
    '''
    Delete a local VPN gateway.

    Required Parameters:
    - name -- Name of the local network gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network local-gateway delete", locals())


def show(name, resource_group):
    '''
    Get the details of a local VPN gateway.

    Required Parameters:
    - name -- Name of the local network gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network local-gateway show", locals())


def list(resource_group):
    '''
    List all local VPN gateways in a resource group.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network local-gateway list", locals())


def create(gateway_ip_address, name, resource_group, asn=None, bgp_peering_address=None, local_address_prefixes=None, location=None, no_wait=None, peer_weight=None, tags=None):
    '''
    Create a local VPN gateway.

    Required Parameters:
    - gateway_ip_address -- Gateway's public IP address. (e.g. 10.1.1.1).
    - name -- Name of the local network gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - asn -- Autonomous System Number to use for the BGP settings.
    - bgp_peering_address -- IP address from the OnPremise VPN's subnet to use for BGP peering.
    - local_address_prefixes -- List of CIDR block prefixes representing the address space of the OnPremise VPN's subnet.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_wait -- Do not wait for the long-running operation to finish.
    - peer_weight -- Weight (0-100) added to routes learned through BGP peering.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az network local-gateway create", locals())


def update(name, resource_group, add=None, asn=None, bgp_peering_address=None, force_string=None, gateway_ip_address=None, local_address_prefixes=None, no_wait=None, peer_weight=None, remove=None, set=None, tags=None):
    '''
    Update a local VPN gateway.

    Required Parameters:
    - name -- Name of the local network gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - asn -- Autonomous System Number to use for the BGP settings.
    - bgp_peering_address -- IP address from the OnPremise VPN's subnet to use for BGP peering.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - gateway_ip_address -- Gateway's public IP address. (e.g. 10.1.1.1).
    - local_address_prefixes -- List of CIDR block prefixes representing the address space of the OnPremise VPN's subnet.
    - no_wait -- Do not wait for the long-running operation to finish.
    - peer_weight -- Weight (0-100) added to routes learned through BGP peering.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az network local-gateway update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the local gateway is met.

    Required Parameters:
    - name -- Name of the local network gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az network local-gateway wait", locals())




'''
View a summary of Batch application packages.
'''
from .... pyaz_utils import _call_az

def list(account_endpoint=None, account_key=None, account_name=None):
    '''
    Lists all of the applications available in the specified account.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    '''
    return _call_az("az batch application summary list", locals())


def show(application_id, account_endpoint=None, account_key=None, account_name=None):
    '''
    Gets information about the specified application.

    Required Parameters:
    - application_id -- The ID of the Application.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    '''
    return _call_az("az batch application summary show", locals())




'''
Manage Data Lake Analytics catalog views.
'''
from .... pyaz_utils import _call_az

def show(account, database_name, schema_name, view_name):
    '''
    

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.
    - database_name -- The name of the database containing the view.
    - schema_name -- The name of the schema containing the view.
    - view_name -- The name of the view.
    '''
    return _call_az("az dla catalog view show", locals())


def list(account, database_name, schema_name=None):
    '''
    List views in a database or schema.

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.
    - database_name -- None

    Optional Parameters:
    - schema_name -- None
    '''
    return _call_az("az dla catalog view list", locals())




'''
Manage object storage for unstructured data (blobs).
'''
from ... pyaz_utils import _call_az
from . import copy, immutability_policy, incremental_copy, lease, metadata


def show(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, lease_id=None, sas_token=None, snapshot=None, tags_condition=None, timeout=None):
    '''
    Get the details of a blob.

    Required Parameters:
    - container_name -- The container name.
    - name -- The blob name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - if_match -- An ETag value, or the wildcard character (*). Specify this header to perform the operation only if the resource's ETag matches the value specified.
    - if_modified_since -- Commence only if modified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - if_none_match -- An ETag value, or the wildcard character (*). Specify this header to perform the operation only if the resource's ETag does not match the value specified. Specify the wildcard character (*) to perform the operation only if the resource does not exist, and fail the operation if it does exist.
    - if_unmodified_since -- Commence only if unmodified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - lease_id -- Required if the blob has an active lease.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - snapshot -- The snapshot parameter is an opaque DateTime value that, when present, specifies the blob snapshot to retrieve.
    - tags_condition -- Specify a SQL where clause on blob tags to operate only on blobs with a matching value.
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage blob show", locals())


def set_tier(container_name, name, tier, account_key=None, account_name=None, auth_mode=None, connection_string=None, rehydrate_priority=None, sas_token=None, timeout=None, type=None):
    '''
    Set the block or page tiers on the blob.

    Required Parameters:
    - container_name -- The container name.
    - name -- The blob name.
    - tier -- None

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - rehydrate_priority -- Indicate the priority with which to rehydrate an archived blob. The priority can be set on a blob only once, default value is Standard.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    - type -- None
    '''
    return _call_az("az storage blob set-tier", locals())


def list(container_name, account_key=None, account_name=None, auth_mode=None, connection_string=None, delimiter=None, include=None, marker=None, num_results=None, prefix=None, sas_token=None, show_next_marker=None, timeout=None):
    '''
    List blobs in a given container.

    Required Parameters:
    - container_name -- The container name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - delimiter -- When the request includes this parameter, the operation returns a BlobPrefix element in the result list that acts as a placeholder for all blobs whose names begin with the same substring up to the appearance of the delimiter character. The delimiter may be a single character or a string.
    - include -- Specify one or more additional datasets to include in the response. Options include: (c)opy, (d)eleted, (m)etadata, (s)napshots, (v)ersions, (t)ags, (i)mmutabilitypolicy, (l)egalhold, (d)eletedwithversions. Can be combined.
    - marker -- A string value that identifies the portion of the list of containers to be returned with the next listing operation. The operation returns the NextMarker value within the response body if the listing operation did not return all containers remaining to be listed with the current page. If specified, this generator will begin returning results from the point where the previous generator stopped.
    - num_results -- Specify the maximum number to return. If the request does not specify num_results, or specifies a value greater than 5000, the server will return up to 5000 items. Note that if the listing operation crosses a partition boundary, then the service will return a continuation token for retrieving the remaining of the results. Provide "*" to return all.
    - prefix -- Filter the results to return only blobs whose name begins with the specified prefix.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - show_next_marker -- Show nextMarker in result when specified.
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage blob list", locals())


def query(container_name, name, query_expression, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, in_column_separator=None, in_escape_char=None, in_has_header=None, in_line_separator=None, in_quote_char=None, in_record_separator=None, input_format=None, lease_id=None, out_column_separator=None, out_escape_char=None, out_has_header=None, out_line_separator=None, out_quote_char=None, out_record_separator=None, output_format=None, result_file=None, sas_token=None, tags_condition=None, timeout=None):
    '''
    Enable users to select/project on blob or blob snapshot data by providing simple query expressions.

    Required Parameters:
    - container_name -- The container name.
    - name -- The blob name.
    - query_expression -- The query expression in SQL. The maximum size of the query expression is 256KiB. For more information about the expression syntax, please see https://docs.microsoft.com/azure/storage/blobs/query-acceleration-sql-reference

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - if_match -- An ETag value, or the wildcard character (*). Specify this header to perform the operation only if the resource's ETag matches the value specified.
    - if_modified_since -- Commence only if modified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - if_none_match -- An ETag value, or the wildcard character (*). Specify this header to perform the operation only if the resource's ETag does not match the value specified. Specify the wildcard character (*) to perform the operation only if the resource does not exist, and fail the operation if it does exist.
    - if_unmodified_since -- Commence only if unmodified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - in_column_separator -- The string used to separate columns.
    - in_escape_char -- The string used as an escape character. Default to empty.
    - in_has_header -- Whether the blob data includes headers in the first line. The default value is False, meaning that the data will be returned inclusive of the first line. If set to True, the data will be returned exclusive of the first line.
    - in_line_separator -- The string used to separate records.
    - in_quote_char -- The string used to quote a specific field.
    - in_record_separator -- The string used to separate records.
    - input_format -- Serialization type of the data currently stored in the blob. The default is to treat the blob data as CSV data formatted in the default dialect.The blob data will be reformatted according to that profile when blob format is specified. If you choose `json`, please specify `Output Json Text Configuration Arguments` accordingly; If you choose `csv`, please specify `Output Delimited Text Configuration Arguments`.
    - lease_id -- Required if the blob has an active lease.
    - out_column_separator -- The string used to separate columns.
    - out_escape_char -- The string used as an escape character. Default to empty.
    - out_has_header -- Whether the blob data includes headers in the first line. The default value is False, meaning that the data will be returned inclusive of the first line. If set to True, the data will be returned exclusive of the first line.
    - out_line_separator -- The string used to separate records.
    - out_quote_char -- The string used to quote a specific field.
    - out_record_separator -- The string used to separate records.
    - output_format -- Output serialization type for the data stream. By default the data will be returned as it is represented in the blob. By providing an output format, the blob data will be reformatted according to that profile. If you choose `json`, please specify `Output Json Text Configuration Arguments` accordingly; If you choose `csv`, please specify `Output Delimited Text Configuration Arguments`.
    - result_file -- Specify the file path to save result.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - tags_condition -- Specify a SQL where clause on blob tags to operate only on blobs with a matching value.
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage blob query", locals())


def rewrite(container_name, name, source_uri, account_key=None, account_name=None, auth_mode=None, connection_string=None, encryption_scope=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, lease_id=None, sas_token=None, tags_condition=None, tier=None, timeout=None):
    '''
    Create a new Block Blob where the content of the blob is read from a given URL.

    Required Parameters:
    - container_name -- The container name.
    - name -- The blob name.
    - source_uri -- A URL of up to 2 KB in length that specifies a file or blob. The value should be URL-encoded as it would appear in a request URI. If the source is in another account, the source must either be public or must be authenticated via a shared access signature. If the source is public, no authentication is required.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - encryption_scope -- A predefined encryption scope used to encrypt the data on the service. An encryption scope can be created using the Management API and referenced here by name. If a default encryption scope has been defined at the container, this value will override it if the container-level scope is configured to allow overrides. Otherwise an error will be raised.
    - if_match -- An ETag value, or the wildcard character (*). Specify this header to perform the operation only if the resource's ETag matches the value specified.
    - if_modified_since -- Commence only if modified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - if_none_match -- An ETag value, or the wildcard character (*). Specify this header to perform the operation only if the resource's ETag does not match the value specified. Specify the wildcard character (*) to perform the operation only if the resource does not exist, and fail the operation if it does exist.
    - if_unmodified_since -- Commence only if unmodified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - lease_id -- Required if the blob has an active lease. Value can be a BlobLeaseClient object or the lease ID as a string.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - tags_condition -- Specify a SQL where clause on blob tags to operate only on blobs with a matching value.
    - tier -- A standard blob tier value to set the blob to. For this version of the library, this is only applicable to block blobs on standard storage accounts.
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage blob rewrite", locals())


def set_legal_hold(container_name, legal_hold, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    Set blob legal hold.

    Required Parameters:
    - container_name -- The container name.
    - legal_hold -- Specified if a legal hold should be set on the blob.
    - name -- The blob name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage blob set-legal-hold", locals())


def download(container_name, file, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, end_range=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, lease_id=None, max_connections=None, no_progress=None, open_mode=None, sas_token=None, snapshot=None, socket_timeout=None, start_range=None, timeout=None, validate_content=None):
    '''
    

    Required Parameters:
    - container_name -- The container name.
    - file --  Path of file to write out to.
    - name -- The blob name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - end_range --  End of byte range to use for downloading a section of the blob. If end_range is given, start_range must be provided. The start_range and end_range params are inclusive. Ex: start_range=0, end_range=511 will download first 512 bytes of blob.
    - if_match --  An ETag value, or the wildcard character (*). Specify this header to perform the operation only if the resource's ETag matches the value specified.
    - if_modified_since -- Commence only if modified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - if_none_match --  An ETag value, or the wildcard character (*). Specify this header to perform the operation only if the resource's ETag does not match the value specified. Specify the wildcard character (*) to perform the operation only if the resource does not exist, and fail the operation if it does exist.
    - if_unmodified_since -- Commence only if unmodified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - lease_id --  Required if the blob has an active lease.
    - max_connections --  If set to 2 or greater, an initial get will be done for the first self.MAX_SINGLE_GET_SIZE bytes of the blob. If this is the entire blob, the method returns at this point. If it is not, it will download the remaining data parallel using the number of threads equal to max_connections. Each chunk will be of size self.MAX_CHUNK_GET_SIZE. If set to 1, a single large get request will be done. This is not generally recommended but available if very few threads should be used, network requests are very expensive, or a non-seekable stream prevents parallel download. This may also be useful if many blobs are expected to be empty as an extra request is required for empty blobs if max_connections is greater than 1.
    - no_progress -- Include this flag to disable progress reporting for the command.
    - open_mode --  Mode to use when opening the file. Note that specifying append only open_mode prevents parallel download. So, max_connections must be set to 1 if this open_mode is used.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - snapshot --  The snapshot parameter is an opaque DateTime value that, when present, specifies the blob snapshot to retrieve.
    - socket_timeout -- The socket timeout(secs), used by the service to regulate data flow.
    - start_range --  Start of byte range to use for downloading a section of the blob. If no end_range is given, all bytes after the start_range will be downloaded. The start_range and end_range params are inclusive. Ex: start_range=0, end_range=511 will download first 512 bytes of blob.
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    - validate_content --  If set to true, validates an MD5 hash for each retrieved portion of the blob. This is primarily valuable for detecting bitflips on the wire if using http instead of https as https (the default) will already validate. Note that the service will only return transactional MD5s for chunks 4MB or less so the first get request will be of size self.MAX_CHUNK_GET_SIZE instead of self.MAX_SINGLE_GET_SIZE. If self.MAX_CHUNK_GET_SIZE was set to greater than 4MB an error will be thrown. As computing the MD5 takes processing time and more requests will need to be done due to the reduced chunk size there may be some increase in latency.
    '''
    return _call_az("az storage blob download", locals())


def generate_sas(container_name, name, account_key=None, account_name=None, as_user=None, auth_mode=None, cache_control=None, connection_string=None, content_disposition=None, content_encoding=None, content_language=None, content_type=None, expiry=None, full_uri=None, https_only=None, ip=None, permissions=None, policy_name=None, start=None):
    '''
    Generate a shared access signature for the blob.

    Required Parameters:
    - container_name -- The container name.
    - name -- The blob name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - as_user -- Indicates that this command return the SAS signed with the user delegation key. The expiry parameter and '--auth-mode login' are required if this argument is specified. 
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - cache_control -- Response header value for Cache-Control when resource is accessed using this shared access signature.
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - content_disposition -- Response header value for Content-Disposition when resource is accessed using this shared access signature.
    - content_encoding -- Response header value for Content-Encoding when resource is accessed using this shared access signature.
    - content_language -- Response header value for Content-Language when resource is accessed using this shared access signature.
    - content_type -- Response header value for Content-Type when resource is accessed using this shared access signature.
    - expiry -- Specifies the UTC datetime (Y-m-d'T'H:M'Z') at which the SAS becomes invalid. Do not use if a stored access policy is referenced with --id that specifies this value.
    - full_uri -- Indicates that this command return the full blob URI and the shared access signature token.
    - https_only -- Only permit requests made with the HTTPS protocol. If omitted, requests from both the HTTP and HTTPS protocol are permitted.
    - ip -- Specifies the IP address or range of IP addresses from which to accept requests. Supports only IPv4 style addresses.
    - permissions -- The permissions the SAS grants. Allowed values: (a)dd (c)reate (d)elete (r)ead (w)rite (a)dd (c)reate (d)elete (r)ead (w)rite. Do not use if a stored access policy is referenced with --id that specifies this value. Can be combined.
    - policy_name -- The name of a stored access policy within the container's ACL.
    - start -- Specifies the UTC datetime (Y-m-d'T'H:M'Z') at which the SAS becomes valid. Do not use if a stored access policy is referenced with --id that specifies this value. Defaults to the time of the request.
    '''
    return _call_az("az storage blob generate-sas", locals())


def url(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, protocol=None, sas_token=None, snapshot=None):
    '''
    Create the url to access a blob.

    Required Parameters:
    - container_name -- The container name.
    - name -- The blob name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - protocol -- Protocol to use.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - snapshot -- An string value that uniquely identifies the snapshot. The value of this query parameter indicates the snapshot version.
    '''
    return _call_az("az storage blob url", locals())


def snapshot(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, lease_id=None, metadata=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - container_name -- The container name.
    - name -- The blob name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - if_match --  An ETag value, or the wildcard character (*). Specify this header to perform the operation only if the resource's ETag matches the value specified.
    - if_modified_since -- Commence only if modified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - if_none_match --  An ETag value, or the wildcard character (*). Specify this header to perform the operation only if the resource's ETag does not match the value specified. Specify the wildcard character (*) to perform the operation only if the resource does not exist, and fail the operation if it does exist.
    - if_unmodified_since -- Commence only if unmodified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - lease_id --  Required if the blob has an active lease.
    - metadata -- Metadata in space-separated key=value pairs. This overwrites any existing metadata.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage blob snapshot", locals())


def update(container_name, name, account_key=None, account_name=None, auth_mode=None, clear_content_settings=None, connection_string=None, content_cache_control=None, content_disposition=None, content_encoding=None, content_language=None, content_md5=None, content_type=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, lease_id=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - container_name -- The container name.
    - name -- The blob name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - clear_content_settings -- If this flag is set, then if any one or more of the following properties (--content-cache-control, --content-disposition, --content-encoding, --content-language, --content-md5, --content-type) is set, then all of these properties are set together. If a value is not provided for a given property when at least one of the properties listed below is set, then that property will be cleared.
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - content_cache_control -- The cache control string.
    - content_disposition -- Conveys additional information about how to process the response payload, and can also be used to attach additional metadata.
    - content_encoding -- The content encoding type.
    - content_language -- The content language.
    - content_md5 -- The content's MD5 hash.
    - content_type -- The content MIME type.
    - if_match --  An ETag value, or the wildcard character (*). Specify this header to perform the operation only if the resource's ETag matches the value specified.
    - if_modified_since -- Commence only if modified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - if_none_match --  An ETag value, or the wildcard character (*). Specify this header to perform the operation only if the resource's ETag does not match the value specified. Specify the wildcard character (*) to perform the operation only if the resource does not exist, and fail the operation if it does exist.
    - if_unmodified_since -- Commence only if unmodified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - lease_id --  Required if the blob has an active lease.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage blob update", locals())


def exists(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, snapshot=None, timeout=None):
    '''
    Check for the existence of a blob in a container.

    Required Parameters:
    - container_name -- The container name.
    - name -- The blob name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - snapshot --  The snapshot parameter is an opaque DateTime value that, when present, specifies the snapshot.
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage blob exists", locals())


def delete(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, delete_snapshots=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, lease_id=None, sas_token=None, snapshot=None, timeout=None):
    '''
    Mark a blob or snapshot for deletion.

    Required Parameters:
    - container_name -- The container name.
    - name -- The blob name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - delete_snapshots --  Required if the blob has associated snapshots.
    - if_match --  An ETag value, or the wildcard character (*). Specify this header to perform the operation only if the resource's ETag matches the value specified.
    - if_modified_since -- Commence only if modified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - if_none_match --  An ETag value, or the wildcard character (*). Specify this header to perform the operation only if the resource's ETag does not match the value specified. Specify the wildcard character (*) to perform the operation only if the resource does not exist, and fail the operation if it does exist.
    - if_unmodified_since -- Commence only if unmodified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - lease_id --  Required if the blob has an active lease.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - snapshot --  The snapshot parameter is an opaque DateTime value that, when present, specifies the blob snapshot to delete.
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage blob delete", locals())


def undelete(container_name, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - container_name -- The container name.
    - name -- The blob name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage blob undelete", locals())


def upload(container_name, file, account_key=None, account_name=None, auth_mode=None, connection_string=None, content_cache_control=None, content_disposition=None, content_encoding=None, content_language=None, content_md5=None, content_type=None, encryption_scope=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, lease_id=None, max_connections=None, maxsize_condition=None, metadata=None, name=None, no_progress=None, sas_token=None, socket_timeout=None, tier=None, timeout=None, type=None, validate_content=None):
    '''
    Upload a file to a storage blob.

    Required Parameters:
    - container_name -- The container name.
    - file --  Path of the file to upload as the blob content.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - content_cache_control -- The cache control string.
    - content_disposition -- Conveys additional information about how to process the response payload, and can also be used to attach additional metadata.
    - content_encoding -- The content encoding type.
    - content_language -- The content language.
    - content_md5 -- The content's MD5 hash.
    - content_type -- The content MIME type.
    - encryption_scope -- A predefined encryption scope used to encrypt the data on the service.
    - if_match --  An ETag value, or the wildcard character (*). Specify this header to perform the operation only if the resource's ETag matches the value specified.
    - if_modified_since -- Commence only if modified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - if_none_match --  An ETag value, or the wildcard character (*). Specify this header to perform the operation only if the resource's ETag does not match the value specified. Specify the wildcard character (*) to perform the operation only if the resource does not exist, and fail the operation if it does exist.
    - if_unmodified_since -- Commence only if unmodified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - lease_id --  Required if the blob has an active lease.
    - max_connections --  Maximum number of parallel connections to use when the blob size exceeds 64MB.
    - maxsize_condition -- None
    - metadata -- Metadata in space-separated key=value pairs. This overwrites any existing metadata.
    - name -- The blob name.
    - no_progress -- Include this flag to disable progress reporting for the command.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - socket_timeout -- The socket timeout(secs), used by the service to regulate data flow.
    - tier -- None
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    - type -- None
    - validate_content --  If true, calculates an MD5 hash for each chunk of the blob. The storage service checks the hash of the content that has arrived with the hash that was sent. This is primarily valuable for detecting bitflips on the wire if using http instead of https as https (the default) will already validate. Note that this MD5 hash is not stored with the blob. Also note that if enabled, the memory-efficient upload algorithm will not be used, because computing the MD5 hash requires buffering entire blocks, and doing so defeats the purpose of the memory-efficient algorithm.
    '''
    return _call_az("az storage blob upload", locals())


def upload_batch(destination, source, account_key=None, account_name=None, auth_mode=None, connection_string=None, content_cache_control=None, content_disposition=None, content_encoding=None, content_language=None, content_md5=None, content_type=None, destination_path=None, dryrun=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, lease_id=None, max_connections=None, maxsize_condition=None, metadata=None, no_progress=None, pattern=None, sas_token=None, socket_timeout=None, timeout=None, type=None, validate_content=None):
    '''
    Upload files from a local directory to a blob container.

    Required Parameters:
    - destination -- None
    - source -- None

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - content_cache_control -- The cache control string.
    - content_disposition -- Conveys additional information about how to process the response payload, and can also be used to attach additional metadata.
    - content_encoding -- The content encoding type.
    - content_language -- The content language.
    - content_md5 -- The content's MD5 hash.
    - content_type -- The content MIME type.
    - destination_path -- The destination path that will be prepended to the blob name.
    - dryrun -- None
    - if_match -- None
    - if_modified_since -- Commence only if modified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - if_none_match -- None
    - if_unmodified_since -- Commence only if unmodified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - lease_id -- None
    - max_connections -- Maximum number of parallel connections to use when the blob size exceeds 64MB.
    - maxsize_condition -- None
    - metadata -- Metadata in space-separated key=value pairs. This overwrites any existing metadata.
    - no_progress -- Include this flag to disable progress reporting for the command.
    - pattern -- None
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - socket_timeout -- The socket timeout(secs), used by the service to regulate data flow.
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    - type -- None
    - validate_content -- None
    '''
    return _call_az("az storage blob upload-batch", locals())


def download_batch(destination, source, account_key=None, account_name=None, auth_mode=None, connection_string=None, dryrun=None, max_connections=None, no_progress=None, pattern=None, sas_token=None, socket_timeout=None):
    '''
    Download blobs from a blob container recursively.

    Required Parameters:
    - destination -- None
    - source -- None

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - dryrun -- None
    - max_connections -- Maximum number of parallel connections to use when the blob size exceeds 64MB.
    - no_progress -- Include this flag to disable progress reporting for the command.
    - pattern -- None
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - socket_timeout -- The socket timeout(secs), used by the service to regulate data flow.
    '''
    return _call_az("az storage blob download-batch", locals())


def delete_batch(source, account_key=None, account_name=None, auth_mode=None, connection_string=None, delete_snapshots=None, dryrun=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, lease_id=None, pattern=None, sas_token=None, timeout=None):
    '''
    Delete blobs from a blob container recursively.

    Required Parameters:
    - source -- None

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - delete_snapshots -- Required if the blob has associated snapshots.
    - dryrun -- None
    - if_match -- None
    - if_modified_since -- Commence only if modified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - if_none_match -- None
    - if_unmodified_since -- Commence only if unmodified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - lease_id -- The active lease id for the blob.
    - pattern -- None
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage blob delete-batch", locals())


def restore(account_name, time_to_restore, blob_range=None, no_wait=None, resource_group=None):
    '''
    Restore blobs in the specified blob ranges.

    Required Parameters:
    - account_name -- The storage account name.
    - time_to_restore -- Restore blob to the specified time, which should be UTC datetime in (Y-m-d'T'H:M:S'Z').

    Optional Parameters:
    - blob_range -- Blob ranges to restore. You need to two values to specify start_range and end_range for each blob range, e.g. -r blob1 blob2. Note: Empty means account start as start range value, and means account end for end range.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage blob restore", locals())


def sync(container, source, account_key=None, account_name=None, auth_mode=None, connection_string=None, destination=None, exclude_path=None, exclude_pattern=None, include_pattern=None, sas_token=None):
    '''
    Sync blobs recursively to a storage blob container.

    Required Parameters:
    - container -- The sync destination container.
    - source -- The source file path to sync from.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - destination -- The destination path that will be prepended to the blob name.
    - exclude_path -- Exclude these paths. This option does not support wildcard characters (*). Checks relative path prefix. For example: myFolder;myFolder/subDirName/file.pdf.
    - exclude_pattern -- Exclude these files where the name matches the pattern list. For example: *.jpg;*.pdf;exactName. This option supports wildcard characters (*)
    - include_pattern -- Include only these files where the name matches the pattern list. For example: *.jpg;*.pdf;exactName. This option supports wildcard characters (*)
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    '''
    return _call_az("az storage blob sync", locals())




'''
Manage Azure NetApp Files (ANF) Volume Backup Resources.
'''
from .... pyaz_utils import _call_az

def show(account_name, backup_name, pool_name, resource_group, volume_name):
    '''
    Get the specified ANF Backup.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - backup_name -- The name of the backup.
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - volume_name -- Name of the ANF volume.
    '''
    return _call_az("az netappfiles volume backup show", locals())


def list(account_name, pool_name, resource_group, volume_name):
    '''
    List the ANF Backups for the specified volume.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - volume_name -- Name of the ANF volume.
    '''
    return _call_az("az netappfiles volume backup list", locals())


def delete(account_name, backup_name, pool_name, resource_group, volume_name):
    '''
    

    Required Parameters:
    - account_name -- Name of the ANF account.
    - backup_name -- The name of the backup.
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - volume_name -- Name of the ANF volume.
    '''
    return _call_az("az netappfiles volume backup delete", locals())


def status(account_name, pool_name, resource_group, volume_name):
    '''
    Get backup status of the specified ANF Volume.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - volume_name -- Name of the ANF volume.
    '''
    return _call_az("az netappfiles volume backup status", locals())


def restore_status(account_name, pool_name, resource_group, volume_name):
    '''
    Get backup restore status of the specified ANF Volume.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - volume_name -- Name of the ANF volume.
    '''
    return _call_az("az netappfiles volume backup restore-status", locals())


def update(account_name, backup_name, pool_name, resource_group, volume_name, label=None, tags=None, use_existing_snapshot=None):
    '''
    Update the specified ANF backup with the values provided.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - backup_name -- None
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - volume_name -- Name of the ANF volume.

    Optional Parameters:
    - label -- Label for backup.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - use_existing_snapshot -- Manual backup an already existing snapshot. This will always be false for scheduled backups and true/false for manual backups.
    '''
    return _call_az("az netappfiles volume backup update", locals())


def create(account_name, backup_name, location, pool_name, resource_group, volume_name, use_existing_snapshot=None):
    '''
    Create specified ANF volume backup.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - backup_name -- None
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - volume_name -- Name of the ANF volume.

    Optional Parameters:
    - use_existing_snapshot -- Manual backup an already existing snapshot. This will always be false for scheduled backups and true/false for manual backups.
    '''
    return _call_az("az netappfiles volume backup create", locals())




'''
Manage role assignments.
'''
from .... pyaz_utils import _call_az

def delete(assignee=None, assignee_object_id=None, hsm_name=None, id=None, ids=None, name=None, role=None, scope=None):
    '''
    

    Optional Parameters:
    - assignee -- represent a user, group, or service principal. supported format: object id, user sign-in name, or service principal name
    - assignee_object_id -- Use this parameter instead of '--assignee' to bypass graph permission issues. This parameter only works with object ids for users, groups, service principals, and managed identities. For managed identities use the principal id. For service principals, use the object id and not the app id.
    - hsm_name -- Name of the HSM.
    - id -- Full URI of the HSM. If specified all other 'Id' arguments should be omitted.
    - ids -- space-separated role assignment ids
    - name -- Name of the role assignment.
    - role -- role name or id
    - scope -- scope at which the role assignment or definition applies to, e.g., "/" or "/keys" or "/keys/{keyname}"
    '''
    return _call_az("az keyvault role assignment delete", locals())


def list(assignee=None, assignee_object_id=None, hsm_name=None, id=None, role=None, scope=None):
    '''
    

    Optional Parameters:
    - assignee -- represent a user, group, or service principal. supported format: object id, user sign-in name, or service principal name
    - assignee_object_id -- Use this parameter instead of '--assignee' to bypass graph permission issues. This parameter only works with object ids for users, groups, service principals, and managed identities. For managed identities use the principal id. For service principals, use the object id and not the app id.
    - hsm_name -- Name of the HSM.
    - id -- Full URI of the HSM. If specified all other 'Id' arguments should be omitted.
    - role -- role name or id
    - scope -- scope at which the role assignment or definition applies to, e.g., "/" or "/keys" or "/keys/{keyname}"
    '''
    return _call_az("az keyvault role assignment list", locals())


def create(role, scope, assignee=None, assignee_object_id=None, assignee_principal_type=None, hsm_name=None, id=None, name=None):
    '''
    

    Required Parameters:
    - role -- role name or id
    - scope -- scope at which the role assignment or definition applies to, e.g., "/" or "/keys" or "/keys/{keyname}"

    Optional Parameters:
    - assignee -- represent a user, group, or service principal. supported format: object id, user sign-in name, or service principal name
    - assignee_object_id -- Use this parameter instead of '--assignee' to bypass graph permission issues. This parameter only works with object ids for users, groups, service principals, and managed identities. For managed identities use the principal id. For service principals, use the object id and not the app id.
    - assignee_principal_type -- The principal type of assignee.
    - hsm_name -- Name of the HSM.
    - id -- Full URI of the HSM. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the role assignment.
    '''
    return _call_az("az keyvault role assignment create", locals())




from .... pyaz_utils import _call_az

def sync(name, resource_group):
    '''
    

    Required Parameters:
    - name -- Name of the Batch account.
    - resource_group -- Name of the resource group
    '''
    return _call_az("az batch account autostorage-keys sync", locals())




'''
Manage Azure EventHubs eventhub and authorization-rule
'''
from ... pyaz_utils import _call_az
from . import authorization_rule, consumer_group


def create(name, namespace_name, resource_group, archive_name_format=None, blob_container=None, capture_interval=None, capture_size_limit=None, destination_name=None, enable_capture=None, message_retention=None, partition_count=None, skip_empty_archives=None, status=None, storage_account=None):
    '''
    Creates the EventHubs Eventhub

    Required Parameters:
    - name -- Name of Eventhub
    - namespace_name -- name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - archive_name_format -- Blob naming convention for archive, e.g. {Namespace}/{EventHub}/{PartitionId}/{Year}/{Month}/{Day}/{Hour}/{Minute}/{Second}. Here all the parameters (Namespace,EventHub .. etc) are mandatory irrespective of order
    - blob_container -- Blob container Name
    - capture_interval -- Allows you to set the frequency with which the capture to Azure Blobs will happen, value should between 60 to 900 seconds
    - capture_size_limit -- Defines the amount of data built up in your Event Hub before an capture operation, value should be between 10485760 to 524288000 bytes
    - destination_name -- Name for capture destination, should be EventHubArchive.AzureBlockBlob.
    - enable_capture -- A boolean value that indicates whether capture description is enabled.
    - message_retention -- Number of days to retain events for this Event Hub, value should be 1 to 7 days and depends on Namespace sku. if Namespace sku is Basic than value should be one and is Manadatory parameter. Namespace sku is standard value should be 1 to 7 days, default is 7 days and is optional parameter
    - partition_count -- Number of partitions created for the Event Hub. By default, allowed values are 2-32. Lower value of 1 is supported with Kafka enabled namespaces. In presence of a custom quota, the upper limit will match the upper limit of the quota.
    - skip_empty_archives -- A boolean value that indicates whether to Skip Empty.
    - status -- Status of Eventhub
    - storage_account -- Name (if within same resource group and not of type Classic Storage) or ARM id of the storage account to be used to create the blobs
    '''
    return _call_az("az eventhubs eventhub create", locals())


def show(name, namespace_name, resource_group):
    '''
    shows the Eventhub Details

    Required Parameters:
    - name -- Name of Eventhub
    - namespace_name -- name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventhubs eventhub show", locals())


def list(namespace_name, resource_group, skip=None, top=None):
    '''
    List the EventHub by Namespace

    Required Parameters:
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - skip -- Skip is only used if a previous operation returned a partial result. If a previous response contains a nextLink element, the value of the nextLink element will include a skip parameter that specifies a starting point to use for subsequent calls.
    - top -- May be used to limit the number of results to the most recent N usageDetails.
    '''
    return _call_az("az eventhubs eventhub list", locals())


def delete(name, namespace_name, resource_group):
    '''
    Deletes the Eventhub

    Required Parameters:
    - name -- Name of Eventhub
    - namespace_name -- name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventhubs eventhub delete", locals())


def update(name, namespace_name, resource_group, add=None, archive_name_format=None, blob_container=None, capture_interval=None, capture_size_limit=None, destination_name=None, enable_capture=None, force_string=None, message_retention=None, partition_count=None, remove=None, set=None, skip_empty_archives=None, status=None, storage_account=None):
    '''
    Updates the EventHubs Eventhub

    Required Parameters:
    - name -- Name of Eventhub
    - namespace_name -- name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - archive_name_format -- Blob naming convention for archive, e.g. {Namespace}/{EventHub}/{PartitionId}/{Year}/{Month}/{Day}/{Hour}/{Minute}/{Second}. Here all the parameters (Namespace,EventHub .. etc) are mandatory irrespective of order
    - blob_container -- Blob container Name
    - capture_interval -- Allows you to set the frequency with which the capture to Azure Blobs will happen, value should between 60 to 900 seconds
    - capture_size_limit -- Defines the amount of data built up in your Event Hub before an capture operation, value should be between 10485760 to 524288000 bytes
    - destination_name -- Name for capture destination, should be EventHubArchive.AzureBlockBlob.
    - enable_capture -- A boolean value that indicates whether capture description is enabled.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - message_retention -- Number of days to retain events for this Event Hub, value should be 1 to 7 days and depends on Namespace sku. if Namespace sku is Basic than value should be one and is Manadatory parameter. Namespace sku is standard value should be 1 to 7 days, default is 7 days and is optional parameter
    - partition_count -- Number of partitions created for the Event Hub. By default, allowed values are 2-32. Lower value of 1 is supported with Kafka enabled namespaces. In presence of a custom quota, the upper limit will match the upper limit of the quota.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - skip_empty_archives -- A boolean value that indicates whether to Skip Empty.
    - status -- Status of Eventhub
    - storage_account -- Name (if within same resource group and not of type Classic Storage) or ARM id of the storage account to be used to create the blobs
    '''
    return _call_az("az eventhubs eventhub update", locals())




from .... pyaz_utils import _call_az

def create(name, resource_group, server_name, subnet, ignore_missing_endpoint=None, vnet_name=None):
    '''
    Create a virtual network rule to allows access to a PostgreSQL server.

    Required Parameters:
    - name -- The name of the vnet rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - subnet -- Name or ID of the subnet that allows access to an Azure Postgres Server. If subnet name is provided, --vnet-name must be provided.

    Optional Parameters:
    - ignore_missing_endpoint -- Create vnet rule before virtual network has vnet service endpoint enabled
    - vnet_name -- The virtual network name
    '''
    return _call_az("az postgres server vnet-rule create", locals())


def delete(name, resource_group, server_name):
    '''
    

    Required Parameters:
    - name -- The name of the vnet rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    '''
    return _call_az("az postgres server vnet-rule delete", locals())


def show(name, resource_group, server_name):
    '''
    

    Required Parameters:
    - name -- The name of the vnet rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    '''
    return _call_az("az postgres server vnet-rule show", locals())


def list(resource_group, server_name):
    '''
    

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    '''
    return _call_az("az postgres server vnet-rule list", locals())


def update(name, resource_group, server_name, subnet, add=None, force_string=None, ignore_missing_endpoint=None, remove=None, set=None, vnet_name=None):
    '''
    Update a virtual network rule.

    Required Parameters:
    - name -- The name of the vnet rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - subnet -- Name or ID of the subnet that allows access to an Azure Postgres Server. If subnet name is provided, --vnet-name must be provided.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - ignore_missing_endpoint -- Create vnet rule before virtual network has vnet service endpoint enabled
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - vnet_name -- The virtual network name
    '''
    return _call_az("az postgres server vnet-rule update", locals())




from .... pyaz_utils import _call_az

def add(dh_group, gateway_name, ike_encryption, ike_integrity, ipsec_encryption, ipsec_integrity, pfs_group, resource_group, sa_lifetime, sa_max_size, no_wait=None):
    '''
    Add a virtual network gateway IPSec policy.

    Required Parameters:
    - dh_group -- The DH Groups used for initial SA.
    - gateway_name -- Virtual network gateway name
    - ike_encryption -- The IKE encryption algorithm.
    - ike_integrity -- The IKE integrity algorithm.
    - ipsec_encryption -- The IPSec encryption algorithm.
    - ipsec_integrity -- The IPSec integrity algorithm.
    - pfs_group -- The Pfs Groups used for new child SA.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sa_lifetime -- The lifetime in seconds for P2S client.
    - sa_max_size -- The payload size in KB for P2S client.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network vnet-gateway ipsec-policy add", locals())


def list(gateway_name, resource_group):
    '''
    List IPSec policies associated with a virtual network gateway.

    Required Parameters:
    - gateway_name -- Virtual network gateway name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network vnet-gateway ipsec-policy list", locals())


def clear(gateway_name, resource_group, no_wait=None):
    '''
    Delete all IPsec policies on a virtual network gateway.

    Required Parameters:
    - gateway_name -- Virtual network gateway name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network vnet-gateway ipsec-policy clear", locals())




from ..... pyaz_utils import _call_az

def add(address_pool, ip_config_name, nic_name, resource_group, gateway_name=None, lb_name=None):
    '''
    Add an address pool to an IP configuration.

    Required Parameters:
    - address_pool -- The name or ID of an existing backend address pool.
    - ip_config_name -- The name of the IP configuration.
    - nic_name -- The network interface (NIC).
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - gateway_name -- The name of an application gateway containing the address pool (Omit if suppying an address pool ID).
    - lb_name -- The name of the load balancer containing the address pool (Omit if suppying an address pool ID).
    '''
    return _call_az("az network nic ip-config address-pool add", locals())


def remove(address_pool, ip_config_name, nic_name, resource_group, gateway_name=None, lb_name=None):
    '''
    Remove an address pool of an IP configuration.

    Required Parameters:
    - address_pool -- The name or ID of an existing backend address pool.
    - ip_config_name -- The name of the IP configuration.
    - nic_name -- The network interface (NIC).
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - gateway_name -- The name of an application gateway containing the address pool (Omit if suppying an address pool ID).
    - lb_name -- The name of the load balancer containing the address pool (Omit if suppying an address pool ID).
    '''
    return _call_az("az network nic ip-config address-pool remove", locals())




'''
Manage custom virtual machine images.
'''
from .. pyaz_utils import _call_az
from . import builder


def create(name, resource_group, source, data_disk_caching=None, data_disk_sources=None, edge_zone=None, hyper_v_generation=None, location=None, os_disk_caching=None, os_type=None, storage_sku=None, tags=None, zone_resilient=None):
    '''
    Create a custom Virtual Machine Image from managed disks or snapshots.

    Required Parameters:
    - name -- new image name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - source -- OS disk source from the same region, including a virtual machine ID or name, OS disk blob URI, managed OS disk ID or name, or OS snapshot ID or name

    Optional Parameters:
    - data_disk_caching -- Storage caching type for the image's data disk.
    - data_disk_sources -- Space-separated list of data disk sources, including unmanaged blob URI, managed disk ID or name, or snapshot ID or name
    - edge_zone -- The name of edge zone.
    - hyper_v_generation -- The hypervisor generation of the Virtual Machine created from the image.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - os_disk_caching -- Storage caching type for the image's OS disk.
    - os_type -- None
    - storage_sku -- The SKU of the storage account with which to create the VM image. Unused if source VM is specified.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - zone_resilient -- Specifies whether an image is zone resilient or not. Default is false. Zone resilient images can be created only in regions that provide Zone Redundant Storage
    '''
    return _call_az("az image create", locals())


def list(resource_group=None):
    '''
    List custom VM images.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az image list", locals())


def show(name, resource_group, expand=None):
    '''
    

    Required Parameters:
    - name -- The name of the image.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - expand -- The expand expression to apply on the operation.
    '''
    return _call_az("az image show", locals())


def delete(name, resource_group):
    '''
    

    Required Parameters:
    - name -- The name of the image.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az image delete", locals())


def update(name, resource_group, add=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Update custom VM images.

    Required Parameters:
    - name -- The name of the image.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az image update", locals())




'''
Manage Batch compute nodes.
'''
from ... pyaz_utils import _call_az
from . import file, remote_desktop, remote_login_settings, scheduling, service_logs, user


def delete(pool_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, json_file=None, node_deallocation_option=None, node_list=None, resize_timeout=None):
    '''
    

    Required Parameters:
    - pool_id -- The ID of the Pool from which you want to remove Compute Nodes.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - if_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service exactly matches the value specified by the client.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_none_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service does not match the value specified by the client.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    - json_file -- A file containing the node remove parameter specification in JSON (formatted to match the respective REST API body). If this parameter is specified, all 'Node Remove Arguments' are ignored.
    - node_deallocation_option -- Determines what to do with a Compute Node and its running task(s) after it has been selected for deallocation. The default value is requeue.
    - node_list -- Required. A maximum of 100 nodes may be removed per request. Space-separated values.
    - resize_timeout -- The default value is 15 minutes. The minimum value is 5 minutes. If you specify a value less than 5 minutes, the Batch service returns an error; if you are calling the REST API directly, the HTTP status code is 400 (Bad Request). Expected format is an ISO-8601 duration.
    '''
    return _call_az("az batch node delete", locals())


def show(node_id, pool_id, account_endpoint=None, account_key=None, account_name=None, select=None):
    '''
    

    Required Parameters:
    - node_id -- The ID of the Compute Node that you want to get information about.
    - pool_id -- The ID of the Pool that contains the Compute Node.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - select -- An OData $select clause.
    '''
    return _call_az("az batch node show", locals())


def list(pool_id, account_endpoint=None, account_key=None, account_name=None, filter=None, select=None):
    '''
    

    Required Parameters:
    - pool_id -- The ID of the Pool from which you want to list Compute Nodes.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - filter -- An OData $filter clause. For more information on constructing this filter, see https://docs.microsoft.com/en-us/rest/api/batchservice/odata-filters-in-batch#list-nodes-in-a-pool.
    - select -- An OData $select clause.
    '''
    return _call_az("az batch node list", locals())


def reboot(node_id, pool_id, account_endpoint=None, account_key=None, account_name=None, node_reboot_option=None):
    '''
    

    Required Parameters:
    - node_id -- The ID of the Compute Node that you want to restart.
    - pool_id -- The ID of the Pool that contains the Compute Node.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - node_reboot_option -- The default value is requeue.
    '''
    return _call_az("az batch node reboot", locals())


def reimage(node_id, pool_id, account_endpoint=None, account_key=None, account_name=None, node_reimage_option=None):
    '''
    

    Required Parameters:
    - node_id -- The ID of the Compute Node that you want to restart.
    - pool_id -- The ID of the Pool that contains the Compute Node.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - node_reimage_option -- The default value is requeue.
    '''
    return _call_az("az batch node reimage", locals())




'''
Manage queue storage messages.
'''
from ... pyaz_utils import _call_az

def put(content, queue_name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, time_to_live=None, timeout=None, visibility_timeout=None):
    '''
    

    Required Parameters:
    - content -- Message content, up to 64KB in size.
    - queue_name -- The queue name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - time_to_live --  Specifies the time-to-live interval for the message, in seconds. The time-to-live may be any positive number or -1 for infinity. If this parameter is omitted, the default time-to-live is 7 days.
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    - visibility_timeout --  If not specified, the default value is 0. Specifies the new visibility timeout value, in seconds, relative to server time. The value must be larger than or equal to 0, and cannot be larger than 7 days. The visibility timeout of a message cannot be set to a value later than the expiry time. visibility_timeout should be set to a value smaller than the time-to-live value.
    '''
    return _call_az("az storage message put", locals())


def get(queue_name, account_key=None, account_name=None, auth_mode=None, connection_string=None, num_messages=None, sas_token=None, timeout=None, visibility_timeout=None):
    '''
    

    Required Parameters:
    - queue_name -- The queue name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - num_messages --  A nonzero integer value that specifies the number of messages to retrieve from the queue, up to a maximum of 32. If fewer are visible, the visible messages are returned. By default, a single message is retrieved from the queue with this operation.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    - visibility_timeout --  Specifies the new visibility timeout value, in seconds, relative to server time. The new value must be larger than or equal to 1 second, and cannot be larger than 7 days. The visibility timeout of a message can be set to a value later than the expiry time.
    '''
    return _call_az("az storage message get", locals())


def peek(queue_name, account_key=None, account_name=None, auth_mode=None, connection_string=None, num_messages=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - queue_name -- The queue name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - num_messages --  A nonzero integer value that specifies the number of messages to peek from the queue, up to a maximum of 32. By default, a single message is peeked from the queue with this operation.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage message peek", locals())


def delete(id, pop_receipt, queue_name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - id --  The message id identifying the message to delete.
    - pop_receipt --  A valid pop receipt value returned from an earlier call to the :func:`~get_messages` or :func:`~update_message`.
    - queue_name -- The queue name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage message delete", locals())


def clear(queue_name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - queue_name -- The queue name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage message clear", locals())


def update(id, pop_receipt, queue_name, visibility_timeout, account_key=None, account_name=None, auth_mode=None, connection_string=None, content=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - id --  The message id identifying the message to update.
    - pop_receipt --  A valid pop receipt value returned from an earlier call to the :func:`~get_messages` or :func:`~update_message` operation.
    - queue_name -- The queue name.
    - visibility_timeout --  Specifies the new visibility timeout value, in seconds, relative to server time. The new value must be larger than or equal to 0, and cannot be larger than 7 days. The visibility timeout of a message cannot be set to a value later than the expiry time. A message can be updated until it has been deleted or has expired.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - content -- Message content, up to 64KB in size.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage message update", locals())




from .... pyaz_utils import _call_az
from . import predefined


def set(gateway_name, resource_group, cipher_suites=None, disabled_ssl_protocols=None, min_protocol_version=None, name=None, no_wait=None, policy_type=None):
    '''
    Update or clear SSL policy settings.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - cipher_suites -- Ssl cipher suites to be enabled in the specified order to application gateway.
    - disabled_ssl_protocols -- Space-separated list of protocols to disable.
    - min_protocol_version -- Minimum version of Ssl protocol to be supported on application gateway. Possible values include: "TLSv1_0", "TLSv1_1", "TLSv1_2".
    - name -- Name of Ssl predefined policy. Possible values include: "AppGwSslPolicy20150501", "AppGwSslPolicy20170401", "AppGwSslPolicy20170401S".
    - no_wait -- Do not wait for the long-running operation to finish.
    - policy_type -- Type of Ssl Policy. Possible values include: "Predefined", "Custom".
    '''
    return _call_az("az network application-gateway ssl-policy set", locals())


def show(gateway_name, resource_group):
    '''
    Get the details of gateway's SSL policy settings.

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway ssl-policy show", locals())


def list_options():
    '''
    Lists available SSL options for configuring SSL policy.
    '''
    return _call_az("az network application-gateway ssl-policy list-options", locals())




from .... pyaz_utils import _call_az

def create(circuit_name, name, resource_group):
    '''
    Create a new link authorization for an ExpressRoute circuit.

    Required Parameters:
    - circuit_name -- ExpressRoute circuit name.
    - name -- Authorization name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route auth create", locals())


def delete(circuit_name, name, resource_group):
    '''
    Delete a link authorization of an ExpressRoute circuit.

    Required Parameters:
    - circuit_name -- ExpressRoute circuit name.
    - name -- Authorization name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route auth delete", locals())


def show(circuit_name, name, resource_group):
    '''
    Get the details of a link authorization of an ExpressRoute circuit.

    Required Parameters:
    - circuit_name -- ExpressRoute circuit name.
    - name -- Authorization name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route auth show", locals())


def list(circuit_name, resource_group):
    '''
    List link authorizations of an ExpressRoute circuit.

    Required Parameters:
    - circuit_name -- ExpressRoute circuit name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route auth list", locals())




'''
Configure hostnames for a web app.
'''
from .... pyaz_utils import _call_az

def add(hostname, resource_group, webapp_name, slot=None):
    '''
    Bind a hostname to a web app.

    Required Parameters:
    - hostname -- hostname assigned to the site, such as custom domains
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - webapp_name -- webapp name. You can configure the default using `az configure --defaults web=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp config hostname add", locals())


def list(resource_group, webapp_name, slot=None):
    '''
    List all hostname bindings for a web app.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - webapp_name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp config hostname list", locals())


def delete(hostname, resource_group, webapp_name, slot=None):
    '''
    Unbind a hostname from a web app.

    Required Parameters:
    - hostname -- hostname assigned to the site, such as custom domains
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - webapp_name -- webapp name. You can configure the default using `az configure --defaults web=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az webapp config hostname delete", locals())


def get_external_ip(resource_group, webapp_name):
    '''
    Get the external-facing IP address for a web app.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - webapp_name -- webapp name. You can configure the default using `az configure --defaults web=<name>`
    '''
    return _call_az("az webapp config hostname get-external-ip", locals())




from .... pyaz_utils import _call_az

def list(dps_name, resource_group):
    '''
    List all linked IoT hubs in an Azure IoT Hub device provisioning service.

    Required Parameters:
    - dps_name -- IoT Provisioning Service name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot dps linked-hub list", locals())


def show(dps_name, linked_hub, resource_group):
    '''
    Show details of a linked IoT hub in an Azure IoT Hub device provisioning service.

    Required Parameters:
    - dps_name -- IoT Provisioning Service name
    - linked_hub -- Host name of linked IoT Hub.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az iot dps linked-hub show", locals())


def create(connection_string, dps_name, location, resource_group, allocation_weight=None, apply_allocation_policy=None, no_wait=None):
    '''
    Create a linked IoT hub in an Azure IoT Hub device provisioning service.

    Required Parameters:
    - connection_string -- Connection string of the IoT hub.
    - dps_name -- IoT Provisioning Service name
    - location -- Location of the IoT hub.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - allocation_weight -- Allocation weight of the IoT hub.
    - apply_allocation_policy -- A boolean indicating whether to apply allocation policy to the IoT hub.
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az iot dps linked-hub create", locals())


def update(dps_name, linked_hub, resource_group, allocation_weight=None, apply_allocation_policy=None, no_wait=None):
    '''
    Update a linked IoT hub in an Azure IoT Hub device provisioning service.

    Required Parameters:
    - dps_name -- IoT Provisioning Service name
    - linked_hub -- Host name of linked IoT Hub.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - allocation_weight -- Allocation weight of the IoT hub.
    - apply_allocation_policy -- A boolean indicating whether to apply allocation policy to the Iot hub.
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az iot dps linked-hub update", locals())


def delete(dps_name, linked_hub, resource_group, no_wait=None):
    '''
    Update a linked IoT hub in an Azure IoT Hub device provisioning service.

    Required Parameters:
    - dps_name -- IoT Provisioning Service name
    - linked_hub -- Host name of linked IoT Hub.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az iot dps linked-hub delete", locals())

